==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/te.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "లైట్బాక్స్ Gallary పారామితులు నిర్వహించండి");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "గ్యాలరీ నిర్వహించండి");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "పూర్తి సైజు చిత్రం వెడల్పు");
define('MANAGE_GALLERY_FULL_HEIGHT', "పూర్తి సైజు చిత్రం ఎత్తు");
define('MANAGE_GALLERY_THUMB_WIDTH', "కూర్పు చిత్రం వెడల్పు");
define('MANAGE_GALLERY_THUMB_HEIGHT', "కూర్పు చిత్రం ఎత్తు");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "ప్రిజర్వ్ థంబ్ కారక నిష్పత్తి");
define('MANAGE_GALLERY_SHOW_TITLES', "శీర్షికలు చూపించు");
define('MANAGE_GALLERY_DISABLE_SORT', "క్రమీకరించు ఆపివేయి");
define('MANAGE_GALLERY_DELETE_IMAGE', "చిత్రాన్ని తొలగించు");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "ఆర్డర్ క్రమీకరించు సేవ్");
define('MANAGE_GALLERY_PUBLISH_MSG', "ప్రచురించడానికి &#39;సరిచేయబడిన&#39; క్లిక్ <br /> మీ అప్లోడ్ చిత్రాలు.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "అన్ని చిత్రాలను షూటింగ్ పూర్తయింది మరియు సెట్టింగులను సేవ్ చేయబడ్డాయి.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "చిత్రాలు పునఃపరిమాణం లేదా సేవ్ సెట్టింగ్లు లోపం ఉంది.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "మీ చిత్రం (లు) అప్లోడ్ చేయబడింది.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "మీ చిత్రం (లు) అప్లోడ్ చేయడంలో ఒక లోపం ఉంది.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "మీరు అప్లోడ్ చేయడానికి ప్రయత్నిస్తున్న ఫైల్ ఒక చిత్రం కాదు.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "మీరు అప్లోడ్ చేయడానికి ప్రయత్నిస్తున్న ఫైల్ చాలా పెద్దది.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "టైటిల్ సేవ్ చెయ్యబడింది.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "మీరు చిత్రం తొలగించాలనుకుంటున్నారా ఖచ్చితంగా");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "చిత్రం తొలగించారు.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "చిత్రం తొలగించడంలో ఒక లోపం ఉంది.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "పారామితులు సేవ్ మరియు పునఃపరిమాణం చిత్రాలు, దయచేసి వేచి ఉండండి ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "అప్లోడ్ అవుతోంది, దయచేసి వేచి ఉండండి ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "క్రమబద్ధీకరణ క్రమం సేవ్ చేయలేదు. మీరు విధమైన క్రమంలో సేవ్ చేయాలనుకుంటున్నారా?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "చిత్రం క్రమబద్ధీకరణ క్రమం సేవ్ చెయ్యబడింది.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "చిత్రం విధమైన దాచేటప్పుడు దోషం ఎదురైంది.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/te.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "లైట్బాక్స్ Gallary పారామితులు నిర్వహించండి");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "గ్యాలరీ నిర్వహించండి");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "పూర్తి సైజు చిత్రం వెడల్పు");
define('MANAGE_GALLERY_FULL_HEIGHT', "పూర్తి సైజు చిత్రం ఎత్తు");
define('MANAGE_GALLERY_THUMB_WIDTH', "కూర్పు చిత్రం వెడల్పు");
define('MANAGE_GALLERY_THUMB_HEIGHT', "కూర్పు చిత్రం ఎత్తు");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "ప్రిజర్వ్ థంబ్ కారక నిష్పత్తి");
define('MANAGE_GALLERY_SHOW_TITLES', "శీర్షికలు చూపించు");
define('MANAGE_GALLERY_DISABLE_SORT', "క్రమీకరించు ఆపివేయి");
define('MANAGE_GALLERY_DELETE_IMAGE', "చిత్రాన్ని తొలగించు");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "ఆర్డర్ క్రమీకరించు సేవ్");
define('MANAGE_GALLERY_PUBLISH_MSG', "ప్రచురించడానికి &#39;సరిచేయబడిన&#39; క్లిక్ <br /> మీ అప్లోడ్ చిత్రాలు.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "అన్ని చిత్రాలను షూటింగ్ పూర్తయింది మరియు సెట్టింగులను సేవ్ చేయబడ్డాయి.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "చిత్రాలు పునఃపరిమాణం లేదా సేవ్ సెట్టింగ్లు లోపం ఉంది.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "మీ చిత్రం (లు) అప్లోడ్ చేయబడింది.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "మీ చిత్రం (లు) అప్లోడ్ చేయడంలో ఒక లోపం ఉంది.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "మీరు అప్లోడ్ చేయడానికి ప్రయత్నిస్తున్న ఫైల్ ఒక చిత్రం కాదు.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "మీరు అప్లోడ్ చేయడానికి ప్రయత్నిస్తున్న ఫైల్ చాలా పెద్దది.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "టైటిల్ సేవ్ చెయ్యబడింది.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "మీరు చిత్రం తొలగించాలనుకుంటున్నారా ఖచ్చితంగా");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "చిత్రం తొలగించారు.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "చిత్రం తొలగించడంలో ఒక లోపం ఉంది.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "పారామితులు సేవ్ మరియు పునఃపరిమాణం చిత్రాలు, దయచేసి వేచి ఉండండి ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "అప్లోడ్ అవుతోంది, దయచేసి వేచి ఉండండి ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "క్రమబద్ధీకరణ క్రమం సేవ్ చేయలేదు. మీరు విధమైన క్రమంలో సేవ్ చేయాలనుకుంటున్నారా?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "చిత్రం క్రమబద్ధీకరణ క్రమం సేవ్ చెయ్యబడింది.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "చిత్రం విధమైన దాచేటప్పుడు దోషం ఎదురైంది.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "మీరు అప్‌లోడ్ చేయడానికి ప్రయత్నిస్తున్న ఫైల్ &#39;upload_max_filesize&#39; లేదా &#39;post_max_size&#39; PHP సెట్టింగ్‌ల కంటే పెద్దది. ఈ పరిమితులను పెంచడానికి మీ సిస్టమ్ నిర్వాహకుడిని సంప్రదించండి.");
?>
